@@ -1,6 +1,6 @@
 /* formatsbr.c - format string interpretation */
 #ifndef	lint
-static char ident[] = "@(#)$Id: formatsbr.c,v 1.24 1993/08/20 15:48:14 jromine Exp $";
+static char ident[] = "@(#)$Id: formatsbr.c,v 1.25 1995/12/06 20:59:41 jromine Exp $";
 #endif	/* lint */
 
 #include "../h/mh.h"
@@ -706,43 +706,44 @@ fmtscan (format, scanl, width, dat)
 	    }
 	    if (fmt -> f_type == FT_LS_ADDR)
 		goto unfriendly;
-	    if ((str = mn -> m_pers) == NULL)
-	        if ((str = mn -> m_note)) {
-	            (void) strcpy (buffer, str);
-	            str = buffer;
-	            if (*str == '(')
-	            	str++;
-	            sp = str + strlen(str) - 1;
-	            if (*sp == ')') {
-	            	*sp-- = '\0';
-	        	while (sp >= str)
-	            	    if (*sp == ' ')
-	            		*sp-- = '\0';
-	            	    else
-	            		break;
-	            }
-	        } else if (!(str = get_x400_friendly (mn -> m_mbox, buffer))) {
-	unfriendly: ;
-		  switch (mn -> m_type) {
+	    if (!(str = mn -> m_pers)
+		    && (!(str = get_x400_friendly (mn -> m_mbox, buffer)))) {
+		if (str = mn -> m_note) {
+		    (void) strcpy (buffer, str);
+		    str = buffer;
+		    if (*str == '(')
+			str++;
+		    sp = str + strlen (str) - 1;
+		    if (*sp == ')') {
+			*sp-- = '\0';
+			while (sp >= str)
+			    if (*sp == ' ')
+				*sp-- = '\0';
+			    else
+				break;
+		    }
+		    if (*str)
+			break;
+		}	    
+
+unfriendly: ;
+		switch (mn -> m_type) {
 		    case LOCALHOST:
-			str = mn -> m_mbox;
+		        str = mn -> m_mbox;
 			break;
 		    case UUCPHOST:
-			(void) sprintf (buffer, "%s!%s",
+			(void) sprintf (str = buffer, "%s!%s",
 					mn -> m_host, mn -> m_mbox);
-			str = buffer;
 			break;
 		    default:
-			if (mn -> m_mbox) {
-			    (void) sprintf (buffer, "%s@%s",
-					    mn -> m_mbox, mn -> m_host);
-			    str= buffer;
-			}
+			if (mn -> m_mbox)
+			    (void) sprintf (str= buffer, "%s@%s", mn -> m_mbox,
+					    mn -> m_host);
 			else
 			    str = mn -> m_text;
 			break;
-		  }
 		}
+	    }
 #endif	/* BERK */
 	    break;
 
