@@ -1,6 +1,6 @@
 /* help.c - print the usage line */
 #ifndef lint
-static char ident[] = "@(#)$Id: help.c,v 1.3 1992/12/15 00:20:22 jromine Exp $";
+static char ident[] = "@(#)$Id: help.c,v 1.4 1994/04/21 19:56:24 jromine Exp $";
 #endif	/*  lint */
 
 #include "../h/mh.h"
@@ -24,6 +24,8 @@ register struct swit   *swp;
     printf ("syntax: %s\n", str);
     printf ("  switches are:\n");
     printsw (ALL, swp, "-");
+    if ((cp = m_find (invo_name)) != NULL)
+	printf ("profile: %s\n", cp);
 
     if (ssequal ("@(#)", cp = version))
 	cp += 4;
