@@ -1,6 +1,6 @@
 /* inc.c - incorporate messages from a maildrop into a folder */
 #ifndef	lint
-static char ident[] = "@(#)$Id: inc.c,v 1.22 1993/09/01 21:41:48 jromine Exp $";
+static char ident[] = "@(#)$Id: inc.c,v 1.24 1994/04/21 18:22:06 jromine Exp $";
 #endif	/* lint */
 
 #ifdef	MAILGROUP
@@ -384,23 +384,17 @@ char   *argv[];
 
 /*  */
 
+#ifdef MAILGROUP
+    return_gid = getegid();	/* Save effective gid, assuming we'll use it */
+    setgid(getgid());		/* Turn off extraordinary privileges */
+#endif	/* MAILGROUP */
+
 #ifdef	POP
     if (host && !*host)
 	host = NULL;
     if (from || !host || rpop <= 0)
 	(void) setuid (getuid ());
 #endif /* POP */
-
-/*
- * 93/12/17 bsa@kf8nh.wariat.org relocated: with MAILGROUP and POP both defined
- * the setgid() call ran as root, and saved gid would be lost.  If the setuid()
- * call above then ran, inc would be unable to reestablish its setgid state.
- */
-#ifdef MAILGROUP
-    return_gid = getegid();	/* Save effective gid, assuming we'll use it */
-    setgid(getgid());		/* Turn off extraordinary privileges */
-#endif	/* MAILGROUP */
-
     if (from) {
 	newmail = from;
 #ifdef	POP
@@ -607,7 +601,7 @@ go_to_it: ;
 	    switch (p = scan (pf, msgnum, 0, nfs, width,
 			file ? 0 : msgnum == mp -> hghmsg + 1 && chgflag,
 			1,	/* check UNSEEN? */
-			0, stop - start, noisy)) {
+			0, 0, stop - start, noisy)) {
 		case SCNEOF: 
 		    printf ("%*d  empty\n", DMAXFOLDER, msgnum);
 		    break;
@@ -701,9 +695,7 @@ go_to_it: ;
 	switch (i = scan (in, msgnum + 1, msgnum + 1, nfs, width,
 		    msgnum == hghnum && chgflag,
 		    1,	/* check UNSEEN? */
-		    0,
-		    0L,
-		    noisy)) {
+		    0, 0, 0L, noisy)) {
 	    case SCNFAT:
 	    case SCNEOF: 
 		break;
@@ -862,7 +854,7 @@ go_to_it: ;
 		switch (scan (in, msgnum, 0, nfs, width,
 			msgnum == mp -> curmsg,
 			1,	/* check UNSEEN? */
-			0,
+			0, 0,
 			fstat (fileno (in), &st) != NOTOK ? (long) st.st_size
 			    : 0L,
 			noisy)) {
