@@ -1,6 +1,6 @@
 /* post.c - enter messages into the transport system */
 #ifndef	lint
-static char ident[] = "@(#)$Id: post.c,v 2.23 1993/08/25 17:26:51 jromine Exp $";
+static char ident[] = "@(#)$Id: post.c,v 2.25 1995/12/06 19:20:22 jromine Exp $";
 #endif	/* lint */
 
 #include "../h/mh.h"
@@ -152,6 +152,11 @@ static struct swit switches[] = {
 #define	QUEUESW 35
     "queued", -6,
 
+#define	RECORSW 36
+    "record program", -6,
+#define	NRECOSW 37
+    "norecord", -8,
+
     NULL, 0
 };
 
@@ -180,6 +185,7 @@ struct headers {
 #define	MRFM	0x0004		/* we've seen a Resent-From: */
 #define	MVIS	0x0008		/* we've seen sighted addrs */
 #define	MINV	0x0010		/* we've seen blind addrs */
+#define	MRPY	0x0020		/* we've seen a Reply-to: */
 };
 
 /*  */
@@ -187,7 +193,7 @@ struct headers {
 static struct headers  NHeaders[] = {
     "Return-Path", HBAD, 0,
     "Received", HBAD, 0,
-    "Reply-To", HADR | HNGR, 0,
+    "Reply-To", HADR | HNGR, MRPY,
     "From", HADR | HNGR, MFRM,
     "Sender", HADR | HBAD, 0,
     "Date", HBAD, 0,
@@ -203,7 +209,7 @@ static struct headers  NHeaders[] = {
 };
 
 static struct headers  RHeaders[] = {
-    "Resent-Reply-To", HADR | HNGR, 0,
+    "Resent-Reply-To", HADR | HNGR, MRPY,
     "Resent-From", HADR | HNGR, MRFM,
     "Resent-Sender", HADR | HBAD, 0,
     "Resent-Date", HBAD, 0,
@@ -213,7 +219,7 @@ static struct headers  RHeaders[] = {
     "Resent-Bcc", HADR | HTRY | HBCC, MINV,
     "Resent-Message-ID", HBAD, 0,
     "Resent-Fcc", HFCC, 0,
-    "Reply-To", HADR, 0,
+    "Reply-To", HADR, MRPY,
     "From", HADR | HNGR, MFRM,
 #ifdef	MMDFI
     "Sender", HADR | HMNG | HNGR, 0,
@@ -269,6 +275,7 @@ static char bccfil[BUFSIZ];
 static char from[BUFSIZ];	/* my network address */
 static char signature[BUFSIZ];	/* my signature */
 static char *filter = NULL;	/* the filter for BCC'ing */
+static char *msgfrom = NULL;	/* the From: field for Bcc'ing */
 static char *subject = NULL;	/* the subject field for BCC'ing */
 static char *fccfold[FCCS];	/* foldernames for FCC'ing */
 
@@ -332,13 +339,15 @@ static char    *partno = NULLCP;
 
 static	int	queued = 0;
 
+static	char   *record = NULLCP;
+
 off_t	lseek ();
 long	time ();
 
 static	putfmt(), start_headers(), finish_headers(), putgrp(), pl();
 static	anno(), make_bcc_file(), verify_all_addresses();
 static	chkadr(), do_addresses(), do_text(), do_an_address(), sigon();
-static 	sigoff(), p_refile(), fcc(), die(), insert_fcc();
+static 	sigoff(), p_refile(), fcc(), die(), insert_fcc(), p_record ();
 static int	get_header(), putadr(), insert(), annoaux();
 #ifdef TMA
 static	postplain();
@@ -575,6 +584,14 @@ char   *argv[];
 		case QUEUESW:
 		    queued++;
 		    continue;
+
+		case RECORSW:
+		    if (!(record = *argp++) || *record == '-')
+			adios (NULLCP, "missing argument to %s", argp[-2]);
+		    continue;
+		case NRECOSW:
+		    record = NULLCP;
+		    continue;
 	    }
 	if (msg)
 	    adios (NULLCP, "only one message at a time!");
@@ -744,6 +761,8 @@ daemon: ;
 
     p_refile (tmpfil);
 
+    p_record ();
+
 #ifdef	MHMTS
     if (!deliver)
 #endif	/* MHMTS */
@@ -806,6 +825,8 @@ register FILE *out;
     }
     msgflags |= (hdr -> set & ~(MVIS | MINV));
 
+    if (hdr -> set & MFRM)
+	msgfrom = msgfrom ? add (str, add (",", msgfrom)) : getcpy (str);
     if (hdr -> flags & HSUB)
 	subject = subject ? add (str, add ("\t", subject)) : getcpy (str);
     if (hdr -> flags & HFCC) {
@@ -847,8 +868,10 @@ register FILE *out;
 		badmsg++;
 
     if (count < 1) {
-	if (hdr -> flags & HNIL)
-	    fprintf (out, "%s: %s", name, str);
+	if (hdr -> flags & HNIL) {
+	    if (!(hdr -> flags & HBCC))
+		fprintf (out, "%s: %s", name, str);
+	}
 	else {
 #ifdef	notdef
 	    advise (NULLCP, "%s: field requires at least one address", name);
@@ -1259,9 +1282,14 @@ static  make_bcc_file () {
 
     fprintf (out, "Date: %s\n", dtime (&tclock));
     if (msgid)
-	fprintf (out, "Message-ID: <%d.%ld@%s>\n",
+	fprintf (out, "Message-ID: <%d.%ld.1@%s>\n",
 		getpid (), tclock, LocalName ());
-    fprintf (out, "From: %s\n", signature);
+    if (msgflags & MFRM) {
+	fprintf (out, "From: %s", msgfrom);
+	fprintf (out, "Sender: %s\n", from);
+    }
+    else
+	fprintf (out, "From: %s\n", signature);
     if (subject)
 	fprintf (out, "Subject: %s", subject);
     fprintf (out, "BCC:\n");
@@ -1283,7 +1311,10 @@ static  make_bcc_file () {
 
 	fprintf (out, "%s: %s\n%s: multipart/digest; boundary=\"",
 		 VRSN_FIELD, VRSN_VALUE, TYPE_FIELD);
-	fprintf (out, "%s\"\n\n--%s\n\n", prefix, prefix);
+	fprintf (out, "%s\"\n%s: %s\n\n--%s\n%s: %s\n%s: %s\n\n", prefix,
+		 DESCR_FIELD, "Blind Carbon Copy", prefix,
+		 TYPE_FIELD, "message/rfc822",
+		 DESCR_FIELD, "Original Message");
     }
     else
 #endif /* MIME */
@@ -2351,6 +2382,77 @@ register char   *file,
     (void) fflush (stdout);
 }
 
+/*    RECORD RECIPIENTS */
+
+static	p_record ()
+{
+    int	    i,
+	    child_id,
+	    status;
+    char    recfile[BUFSIZ];
+    register struct mailname  *ap,
+			     **app;
+    struct mailname *addrs[3];
+    register FILE   *out;
+
+    if (!record || (msgflags & (MFRM | MRFM | MRPY)))
+	return;
+
+    addrs[0] = &localaddrs;
+    addrs[1] = &netaddrs;
+    addrs[2] = NULL;
+    if (verbose) {
+	printf ("recording recipients... ");
+	fflush (stdout);
+    }
+
+    (void) strcpy (recfile, m_tmpfil ("record"));
+    if ((out = fopen (recfile, "w")) == NULL) {
+	fprintf (verbose ? stdout : stderr, "unable to create temporary file");
+	if (!verbose)
+	    fprintf (stderr, ", so can't record recipients");
+	fprintf (verbose ? stdout : stderr, "\n");
+	return;
+    }
+    (void) chmod (recfile, 0600);
+
+    for (app = addrs; ap = *app; app++) {
+	register struct mailname *mp;
+
+	for (mp = ap -> m_next; mp; mp = mp -> m_next)
+	    fprintf (out, "%s\n", adrformat (mp));
+    }
+
+    (void) fclose (out);
+
+    for (i = 0; (child_id = fork ()) == NOTOK && i < 5; i++)
+	sleep (5);
+    switch (child_id) {
+	case NOTOK:
+	    fprintf (verbose ? stdout : stderr, "unable to fork");
+	    if (!verbose)
+		fprintf (stderr, ", so can't record recipients");
+	    fprintf (verbose ? stdout : stderr, "\n");
+	    break;
+
+	case OK:
+	    execlp (record, r1bindex (record, '/'), recfile, NULLCP);
+	    _exit (-1);
+
+	default:
+	    if (status = pidwait (child_id, OK)) {
+		if (!verbose)
+		    fprintf (stderr, "problem with %s: ", recfile);
+		(void) pidstatus (status, verbose ? stdout : stderr, NULLCP);
+	    }
+	    else
+		if (verbose)
+		    printf ("done\n");
+    }
+
+    (void) unlink (recfile);
+}
+
 /*    TERMINATION */
 
 /* VARARGS2 */
