@@ -1,6 +1,6 @@
 /* whatnowsbr.c - the WhatNow shell */
 #ifndef	lint
-static char ident[] = "@(#)$Id: whatnowsbr.c,v 1.21 1992/12/15 00:20:22 jromine Exp $";
+static char ident[] = "@(#)$Id: whatnowsbr.c,v 1.24 1995/12/06 21:04:47 jromine Exp $";
 #endif	/* lint */
 
 #include "../h/mh.h"
@@ -523,7 +523,7 @@ char   *msgnam;
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
-	        if (uprf (name, XXX_FIELD_PRF)) {
+	        if (uleq (name, VRSN_FIELD) || uprf (name, XXX_FIELD_PRF)) {
 		    (void) fclose (fp);
 		    return 0;
 		}
@@ -653,6 +653,14 @@ static struct swit  sendswitches[] = {
 #define SNDRFSW 34
     "nodraftfolder", -3,
 
+#define	QUEUESW 35
+    "queued", -6,
+
+#define	RECORSW 36
+    "record program", -6,
+#define	NRECOSW 37
+    "norecord", -8,
+
     NULL, 0
 };
 
@@ -780,6 +788,8 @@ int     pushed;
 		case ENCRSW: 
 		case NENCRSW: 
 		case SNOOPSW: 
+		case QUEUESW: 
+		case NRECOSW: 
 		    vec[vecp++] = --cp;
 		    continue;
 
@@ -788,6 +798,7 @@ int     pushed;
 		case WIDTHSW: 
 		case CLIESW: 
 		case SERVSW: 
+		case RECORSW: 
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-') {
 			advise (NULLCP, "missing argument to %s", argp[-2]);
